# shapely_ext
It's a shapely extension package for shapely user.
shapely_ext provides lots of magic util based on shapely, including interpolate, mesh, space explore,
 angle and decomposition
 
 
## install
`pip install shapely_ext`

## TODO
1. write a tutorial
2. refactor space explorer
3. implement a magic snap function
4. implement filling util
